@@ -483,6 +483,8 @@ def parse_datetime(
                         else datetime(year, month, day, hour, min, sec)
                     )
             except Exception as e:
+                if only_check:
+                    return True
                 raise JSONSingletonException(
                     f"Error on introduced datetime. {e}"
                 ) from None
@@ -514,7 +516,7 @@ def parse_bool(s, fail_silently=False):
         raise JSONSingletonException(f"Can't parse target bool: {s}")
 
 
-def parse_json(s):
+def parse_json(s, **kwargs):
     """Parse all jsons from a text string or URL"""
 
     if not isinstance(s, str):
@@ -522,7 +524,7 @@ def parse_json(s):
     output = QuerySet(list_of_root_nodes=True)
 
     if url_validator(s):
-        req = retry_function(requests.get, s)
+        req = retry_function(requests.get, s, **kwargs)
         s = req.text
 
     def extract_json_objects(text, decoder=JSONDecoder()):
